@@ -30,6 +30,13 @@ around BUILDARGS => sub {
         %options = (
             apiurl => 'http://identi.ca/api',
             apirealm => 'Laconica API',
+            oauth_urls => {
+                request_token_url  => "https://identi.ca/api/oauth/request_token",
+                authentication_url => "https://identi.ca/api/oauth/authenticate",
+                authorization_url  => "https://identi.ca/api/oauth/authorize",
+                access_token_url   => "https://identi.ca/api/oauth/access_token",
+                xauth_url          => "https://identi.ca/api/oauth/access_token",
+            },
             %options,
         );
     }
@@ -37,12 +44,6 @@ around BUILDARGS => sub {
     return $next->($class, \%options);
 };
 
-after credentials => sub {
-    my $self = shift;
-
-    $self->ua->credentials($self->apihost, $self->apirealm, $self->username, $self->password);
-};
-
 base_url     'apiurl';
 authenticate 1;
 
